@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 BEGIN {
-  $CPAN::Perl::Releases::VERSION = '0.16';
+  $CPAN::Perl::Releases::VERSION = '0.18';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -194,6 +194,10 @@ our $data =
     "tar.bz2" => "J/JE/JESSE/perl-5.14.1-RC1.tar.bz2",
     "tar.gz" => "J/JE/JESSE/perl-5.14.1-RC1.tar.gz",
   },
+  "5.14.1" => {
+    "tar.bz2" => "J/JE/JESSE/perl-5.14.1.tar.bz2",
+    "tar.gz" => "J/JE/JESSE/perl-5.14.1.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -302,7 +306,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.16
+version 0.18
 
 =head1 SYNOPSIS
 
